@@ -1,9 +1,8 @@
-from . import _LOGGER
 from .const import TEXT_UNKNOWN
 from .helpers import _WiserSignalStrength
 
 class _WiserDevice(object):
-    """Class representing a wiser device"""
+    """Class representing a wiser heating device"""
 
     def __init__(self, data: dict):
         self._data = data
@@ -53,3 +52,20 @@ class _WiserDevice(object):
     def signal(self) -> _WiserSignalStrength:
         """Get zwave network information"""
         return self._signal
+
+class _WiserElectricalDevice(_WiserDevice):
+    """Class representing a wiser electrical device"""
+    def __init__(self, data: dict, device_type_data: dict):
+        self._device_type_data = device_type_data
+        super().__init__(data)
+
+    @property
+    def id(self) -> int:
+        """Get id of device"""
+        return self._device_type_data.get("DeviceId")
+
+    # Lights and shutters currently have model identifier as Unknowm
+    @property
+    def model(self) -> str:
+        """Get model of device"""
+        return self._data.get("ProductType", TEXT_UNKNOWN)
